<?php

namespace Crm\Coupon\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Crm\Coupon\Actions\CouponAction;
use Crm\Coupon\Http\Requests\CouponActionRequest;
use Crm\Coupon\Http\Resources\CouponResource;
use Crm\Coupon\Models\Coupon;

/**
 * Admin web controller class.
 */
class CouponActionController extends BaseController
{

    /**
     * Action controller function for coupon.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(CouponActionRequest $request, Coupon $coupon, $action)
    {
        try {
            $request = $request->all();
            $coupon = CouponAction::run($action, $coupon, $request);

            $data = new CouponResource($coupon);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('coupon::coupon.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('coupon/coupon/' . $coupon->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('coupon/coupon/' . $coupon->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
