<?php

namespace Crm\Coupon\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Illuminate\Support\Str;
use Crm\Coupon\Actions\CouponExim;
use Crm\Coupon\Http\Requests\CouponEximRequest;

/**
 * Admin web controller class.
 */
class CouponEximController extends BaseController
{
    /**
     * Action controller function for coupon.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(CouponEximRequest $request, $exim)
    {
        try {
            $function = Str::camel($exim);
            $data = CouponExim::$function($request);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('coupon:coupon.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('coupon/coupon/' . $exim))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('coupon/coupon/' . $exim))
                ->redirect();
        }
    }
}
