<?php

namespace Crm\Coupon\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Crm\Coupon\Events\CouponWorkflow as CouponWorkflowEvent;
use Crm\Coupon\Notifications\CouponWorkflow as CouponWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class CouponWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(CouponWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $coupon is submitted.
     *
     * @param CouponWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(CouponWorkflowEvent $event)
    {
        $client = $event->coupon->client;
        Notification::send($client, new CouponWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $coupon is published.
     *
     * @param CouponWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(CouponWorkflowEvent $event)
    {
        $client = $event->coupon->client;
        Notification::send($client, new CouponWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $coupon is approved.
     *
     * @param CouponWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(CouponWorkflowEvent $event)
    {
        $client = $event->coupon->client;
        Notification::send($client, new CouponWorkflowNotification($event));
    }

    /**
     * Handles the $coupon workflow event as a listener.
     *
     * @param CouponWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(CouponWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
