<?php
namespace Crm\Coupon\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Crm\Coupon\Events\CouponAction as CouponActionEvent;
use Crm\Coupon\Models\Coupon;

class CouponAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $coupon;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param CouponActionEvent $coupon
     */
    public function __construct(CouponActionEvent $coupon)
    {
        $this->action = $event->action;
        $this->coupon = $coupon;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Coupon Approved - ' . config('app.name'))
            ->view('coupon::coupon.email.action', ['data' => $this->coupon]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
