<?php

namespace Crm\Coupon\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Crm\Coupon\Models\Coupon;

class CouponPolicy
{

    use CouponAction;
    use CouponExim;
    use CouponWorkflow;

    /**
     * Determine if the given user can view the coupon.
     *
     * @param Authenticatable $user
     * @param Coupon $coupon
     *
     * @return bool
     */
    public function view(Authenticatable $user, Coupon $coupon)
    {
        if ($authUser->canDo('coupon.coupon.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $coupon->is_owner;
    }

    /**
     * Determine if the given user can create a coupon.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('coupon.coupon.create');
    }

    /**
     * Determine if the given user can update the given coupon.
     *
     * @param Authenticatable $user
     * @param Coupon $coupon
     *
     * @return bool
     */
    public function update(Authenticatable $user, Coupon $coupon)
    {
        if ($user->canDo('coupon.coupon.edit') && $user->isAdmin()) {
            return true;
        }

        return $coupon->is_owner;
    }

    /**
     * Determine if the given user can delete the given coupon.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Coupon $coupon)
    {
        return $coupon->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
