<?php

namespace Crm\Coupon\Providers;

use Illuminate\Support\ServiceProvider;
use Crm\Coupon\Coupons;

class CouponServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'coupon');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'coupon');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();

        $this->app->register(\Crm\Coupon\Providers\AuthServiceProvider::class);
        $this->app->register(\Crm\Coupon\Providers\RouteServiceProvider::class);
        $this->app->register(\Crm\Coupon\Providers\ActionServiceProvider::class);
        $this->app->register(\Crm\Coupon\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('crm.coupon', function($app)
        {
            return $this->app->make(Coupon::class);
        });
    }

    /**
     * Merges user's and coupon's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'crm.coupon'
        );
        
        
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/coupon.php', 'crm.coupon.coupon'
        );
    }


    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['crm.coupon'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/' => config_path('crm/coupon')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/coupon')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/coupon')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
